==> 2.5.zip: piwigo/language/eo_EO/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['SQL queries'] = 'SQL petoj';
$lang['Upgrade informations'] = 'Informoj pri la ĝisdatigo';
$lang['User permissions and group permissions have been erased'] = 'La permesoj de uzantoj kaj de grupoj viŝiĝis';
$lang['You do not have access rights to run upgrade'] = 'Vi ne havas akcesrajtojn por lanĉi ĝisdatigon';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Tiu-ĉi paĝo proponas ĝisdatigi la datenbazon de via eksa Piwigo-versio al la nova. La ĝisdatiga asistanto pensas ke vi nun funkciigas <strong>versio %s</strong> (aŭ simila).';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Plenumu funkcitenan kontrolon en [Administrado>Iloj>Funkciteno] se vi alfrontas problemon.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Nur la miniatura prefikso kaj la retestra retadreso konserviĝis el la antaŭa agordo';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Kiel singardo, la jenaj temoj malaktiviĝis. Kontrolserĉu ĝisdatigojn antaŭ ol reaktivigi ilin:';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kiel singardo, la jenaj krom-programoj malaktiviĝis. Kontrolserĉu ĝisdatigojn antaŭ ol reaktivigi ilin:';
$lang['total upgrade time'] = 'kompleta ĝisdatigotempo';
$lang['total SQL time'] = 'kompleta SQL-tempo';
$lang['Upgrade from version %s to %s'] = 'Ĝisdatigu de versio %s al %s';
$lang['Upgrade'] = 'Ĝisdatigi';
$lang['Statistics'] = 'Statistikoj';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Nur administranto povas lanĉi ĝisdatigadon: bonvolu ensaluti ĉisube.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, antaŭ <b>?></b>, enmetu:';
$lang['All sub-albums of private albums become private'] = 'Ĉiuj sub-fotaroj el privataj fotaroj iĝas privataj';
?>

==> 14.5.0.zip: piwigo/language/eo_EO/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['SQL queries'] = 'SQL petoj';
$lang['Upgrade informations'] = 'Informoj pri la ĝisdatigo';
$lang['User permissions and group permissions have been erased'] = 'La permesoj de uzantoj kaj de grupoj viŝiĝis';
$lang['You do not have access rights to run upgrade'] = 'Vi ne havas akcesrajtojn por lanĉi ĝisdatigon';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Tiu-ĉi paĝo proponas ĝisdatigi la datenbazon de via eksa Piwigo-versio al la nova. La ĝisdatiga asistanto pensas ke vi nun funkciigas <strong>versio %s</strong> (aŭ simila).';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Plenumu funkcitenan kontrolon en [Administrado>Iloj>Funkciteno] se vi alfrontas problemon.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Nur la miniatura prefikso kaj la retestra retadreso konserviĝis el la antaŭa agordo';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Kiel singardo, la jenaj temoj malaktiviĝis. Kontrolserĉu ĝisdatigojn antaŭ ol reaktivigi ilin:';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kiel singardo, la jenaj krom-programoj malaktiviĝis. Kontrolserĉu ĝisdatigojn antaŭ ol reaktivigi ilin:';
$lang['total upgrade time'] = 'kompleta ĝisdatigotempo';
$lang['total SQL time'] = 'kompleta SQL-tempo';
$lang['Upgrade from version %s to %s'] = 'Ĝisdatigu de versio %s al %s';
$lang['Upgrade'] = 'Ĝisdatigi';
$lang['Statistics'] = 'Statistikoj';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Nur administranto povas lanĉi ĝisdatigadon: bonvolu ensaluti ĉisube.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, antaŭ <b>?></b>, enmetu:';
$lang['All sub-albums of private albums become private'] = 'Ĉiuj sub-fotaroj el privataj fotaroj iĝas privataj';
$lang['Discover what\'s new in Piwigo %s'] = 'Malkovru kion novas en Piwigo %s';
